CALIGARI 1
===============================================================================

NAME
-------------------------------------------------------------------------------

caligari - symbolically link external configuration files

SYNOPSIS
-------------------------------------------------------------------------------

`caligari` [*OPTION*]... [*PATH*]...

DESCRIPTION
-------------------------------------------------------------------------------

`caligari` installs configuration files by symbolically linking all of the
files from the given paths directly to the current user's home directory with
the same relative file structure, creating any requisite directories as-needed.


OPTIONS
-------------------------------------------------------------------------------

`-x`, `--exclude` *pattern* ...
  Exclude the files and directories matching the given patterns. Patterns may
  be supplied as *fnmatch* patterns. Note that exclusions are automatically
  given the **FNM_DOTMATCH** and **FNM_PATHNAME** flags.

`-f`, `--force`
  Force installation over existing files.

`-s`, `--simulate`
  Simulate installation (implies `--verbose`). Any action which would normally
  affect the file system is simply reported rather than acted upon.

`-t`, `--traverse`
  Traverse into the given directories while processing. This ensures that each
  path given acts as its own relative "root" path during processing -- the
  files in each path will be linked directly to the user's home directory
  rather than being treated as children of the current working directory.

`-V`, `--verbose`
  Print verbose installation information while processing. Each item printed
  by this flag is announced with an appropriate label for the action being
  taken (or simulated): `ln:` for created symbolic links, `path:` for created
  directory paths, `rm:` for unlinked files, and `err:` for any errors
  encountered.

CONFIGURATION
-------------------------------------------------------------------------------

`caligari` may be configured by editing the system-wide configuration file
(defined by default as */etc/xdg/caligari.yml*) or the per-user configuration
file (defined by default as *~/.config/caligari.yml*). These configuration
files are simple YAML files which define the default exclusion patterns used
by `caligari`.

EXAMPLES
-------------------------------------------------------------------------------

Create symbolic links for all of the files in the current directory excluding
the *.git* directory and all *README.md* files:

```sh
caligari -x '**/.git' '**/README.md'
```

Forcefully create symbolic links for all of the files in the directories
*dotfiles* and *more-dotfiles*, traversing to each so the files are linked
directly to the home directory:

```sh
caligari -tf dotfiles more-dotfiles
```

Print each file which was forcefully removed:

```sh
caligari -Vf | awk '/^rm:/ { print $2 }'
```

Example *~/.config/caligari.yml* to automatically exclude the *.git* directory
and all *README.md* files:

```yaml
---
:exclude:
- "**/.git"
- "**/README.md"
```

FILES
-------------------------------------------------------------------------------

*/etc/xdg/caligari.yml*
  The system-wide configuration file.

*~/.config/caligari.yml*
  Per-user configuration file.

AUTHOR
-------------------------------------------------------------------------------

Robin Owen <vthrenody@gmail.com>
